%if 0%{?fedora} || 0%{?rhel} >= 8
%global with_py3 1
%endif

%global srcname persistent

Name:           python-%{srcname}
Version:        4.2.4
Release:        1%{?dist}
Summary:        Translucent persistent python objects

License:        ZPLv2.1
URL:            http://www.zodb.org/
Source0:        https://github.com/zopefoundation/%{srcname}/archive/%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  python2-cffi
BuildRequires:  python2-devel
BuildRequires:  python2-nose
BuildRequires:  python2-repoze-sphinx-autointerface
BuildRequires:  python2-setuptools
BuildRequires:  python2-sphinx
BuildRequires:  python-zope-interface

%if 0%{?with_py3}
BuildRequires:  python3-cffi
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-repoze-sphinx-autointerface
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-zope-interface
%endif

%global common_desc                                                        \
This package contains a generic persistence implementation for Python.  It \
forms the core protocol for making objects interact transparently with a   \
database such as python-ZODB3.

%description
%{common_desc}

%package -n python2-%{srcname}
Summary:        Translucent persistent python objects
Requires:       python-zope-interface%{?_isa}

%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{common_desc}

%package -n python2-%{srcname}-devel
Summary:        Development files for python2-%{srcname}
Requires:       python2-%{srcname} = %{version}-%{release}
BuildArch:      noarch

%{?python_provide:%python_provide python2-%{srcname}-devel}

%description -n python2-%{srcname}-devel
Header files for building applications that use python-%{srcname}.

%package -n python2-%{srcname}-doc
Summary:        Documentation for python2-%{srcname}
Requires:       python2-%{srcname} = %{version}-%{release}
BuildArch:      noarch

Provides:       bundled(jquery)
%{?python_provide:%python_provide python2-%{srcname}-doc}

%description -n python2-%{srcname}-doc
Documentation for python2-%{srcname}.

%if 0%{?with_py3}
%package -n python3-%{srcname}
Summary:        Translucent persistent python objects
Requires:       python3-zope-interface%{?_isa}

%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
%{common_desc}

%package -n python3-%{srcname}-devel
Summary:        Development files for python3-%{srcname}
Requires:       python3-%{srcname} = %{version}-%{release}
BuildArch:      noarch

%{?python_provide:%python_provide python3-%{srcname}-devel}

%description -n python3-%{srcname}-devel
Header files for building applications that use python3-%{srcname}.

%package -n python3-%{srcname}-doc
Summary:        Documentation for python3-%{srcname}
Requires:       python3-%{srcname} = %{version}-%{release}
BuildArch:      noarch

Provides:       bundled(jquery)
%{?python_provide:%python_provide python3-%{srcname}-doc}

%description -n python3-%{srcname}-doc
Documentation for python3-%{srcname}.
%endif

%prep
%setup -q -c

# Add an overlooked header file
sed -i "s|headers = \[|&'persistent/_compat.h',\n               |" \
    %{srcname}-%{version}/setup.py

%if 0%{?fedora} >= 24
# Update the sphinx theme name
sed -i "s/'default'/'alabaster'/" %{srcname}-%{version}/docs/conf.py
%endif

%if 0%{?with_py3}
# Prepare for a python3 build
cp -a %{srcname}-%{version} python3-%{srcname}-%{version}
%endif

%build
# Python 2 build
pushd %{srcname}-%{version}
%py2_build
PYTHONPATH=$(echo $PWD/build/lib.linux-*) make -C docs html \
  SPHINXBUILD=%{_bindir}/sphinx-build-%{python2_version}
popd

%if 0%{?with_py3}
# Python 3 build
pushd python3-%{srcname}-%{version}
%py3_build
PYTHONPATH=$(echo $PWD/build/lib.linux-*) make -C docs html \
  SPHINXBUILD=%{_bindir}/sphinx-build-%{python3_version}
popd
%endif

%install
# Python 2 install
pushd %{srcname}-%{version}
%py2_install
popd

%if 0%{?with_py3}
# Python 3 install
pushd python3-%{srcname}-%{version}
%py3_install
popd
%endif

# Remove unwanted documentation and source files; fix permissions (Python 2)
rm -f %{srcname}-%{version}/docs/_build/html/.buildinfo
rm -f %{buildroot}%{python2_sitearch}/%{srcname}/*.{c,h}
chmod 0755 %{buildroot}%{python2_sitearch}/%{srcname}/*.so

%if 0%{?with_py3}
# Remove unwanted documentation and source files; fix permissions (Python 3)
rm -f python3-%{srcname}-%{version}/docs/_build/html/.buildinfo
rm -f %{buildroot}%{python3_sitearch}/%{srcname}/*.{c,h}
chmod 0755 %{buildroot}%{python3_sitearch}/%{srcname}/*.so
%endif

%check
export USING_CFFI=true

# Python 2 tests
pushd %{srcname}-%{version}
nosetests-%{python2_version}
popd

%if 0%{?with_py3}
# Python 3 tests
pushd python3-%{srcname}-%{version}
nosetests-%{python3_version}
popd
%endif

%files -n python2-%{srcname}
%license %{srcname}-%{version}/LICENSE.txt
%{python2_sitearch}/%{srcname}*

%files -n python2-%{srcname}-devel
%{_includedir}/python2.*/%{srcname}/

%files -n python2-%{srcname}-doc
%doc %{srcname}-%{version}/docs/_build/html/*

%if 0%{?with_py3}
%files -n python3-%{srcname}
%license %{srcname}-%{version}/LICENSE.txt
%{python3_sitearch}/%{srcname}*

%files -n python3-%{srcname}-devel
%{_includedir}/python3.*/%{srcname}/

%files -n python3-%{srcname}-doc
%doc python3-%{srcname}-%{version}/docs/_build/html/*
%endif

%changelog
* Tue Mar 21 2017 Jerry James <loganjerry@gmail.com> - 4.2.4-1
- New upstream version

* Thu Mar  9 2017 Jerry James <loganjerry@gmail.com> - 4.2.3-1
- New upstream version

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Dec 21 2016 Jerry James <loganjerry@gmail.com> - 4.2.2-3
- Install a header file that upstream overlooked

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 4.2.2-2
- Rebuild for Python 3.6

* Fri Dec  2 2016 Jerry James <loganjerry@gmail.com> - 4.2.2-1
- New upstream version

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Fri May 27 2016 Jerry James <loganjerry@gmail.com> - 4.2.1-1
- New upstream version

* Sat May  7 2016 Jerry James <loganjerry@gmail.com> - 4.2.0-1
- New upstream version

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Feb  1 2016 Jerry James <loganjerry@gmail.com> - 4.1.1-3
- Comply with latest python packaging guidelines

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jun  5 2015 Jerry James <loganjerry@gmail.com> - 4.1.1-1
- New upstream version

* Sat May 23 2015 Jerry James <loganjerry@gmail.com> - 4.1.0-1
- New upstream version
- Drop upstreamed -timestamp patch

* Tue Apr 14 2015 Jerry James <loganjerry@gmail.com> - 4.0.9-1
- New upstream version

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jun  3 2014 Jerry James <loganjerry@gmail.com> - 4.0.8-2
- Conditionalize python 3 build
- Remove %%clean script

* Thu May 29 2014 Jerry James <loganjerry@gmail.com> - 4.0.8-1
- Initial RPM (bz 1102950)
